@@ -252,6 +252,10 @@ def get_args():
                             dest='storagedata_url',
                             default='',
                             help='URL for downloading DDM end points data')
+    arg_parser.add_argument('--rucio-host',
+                            dest='rucio_host',
+                            default='',
+                            help='URL for the Rucio host (optional)')
 
     # Country group
     arg_parser.add_argument('--country-group',
@@ -460,9 +464,10 @@ def set_environment_variables():
         environ['PILOT_OUTPUT_DIR'] = args.output_dir
 
     # keep track of the server urls
-    environ['PANDA_SERVER_URL'] = get_panda_server(args.url, args.port)
+    environ['PANDA_SERVER_URL'] = get_panda_server(args.url, args.port, update_server=args.update_server)
     environ['QUEUEDATA_SERVER_URL'] = '%s' % args.queuedata_url
-    environ['STORAGEDATA_SERVER_URL'] = '%s' % args.storagedata_url
+    if args.storagedata_url:
+        environ['STORAGEDATA_SERVER_URL'] = '%s' % args.storagedata_url
 
 
 def wrap_up():
@@ -510,6 +515,13 @@ def wrap_up():
         elif trace.pilot['state'] == ERRNO_NOJOBS:
             logging.critical('pilot did not process any events -- aborting')
             exitcode = ERRNO_NOJOBS
+
+    try:
+        exitcode = int(exitcode)
+    except TypeError as exc:
+        logging.warning(f'failed to convert exit code to int: {exitcode}, {exc}')
+        exitcode = 1008
+
     logging.info('pilot has finished')
     logging.shutdown()
 
@@ -568,6 +580,7 @@ if __name__ == '__main__':
     # get the args from the arg parser
     args = get_args()
     args.last_heartbeat = time.time()
+    # args.rucio_host = 'https://voatlasrucio-server-prod.cern.ch:443'
 
     # Define and set the main harvester control boolean
     args.harvester = is_harvester_mode(args)
