@@ -20,6 +20,7 @@ from re import findall, split
 from pilot.control.payloads import generic, eventservice, eventservicemerge
 from pilot.control.job import send_state
 from pilot.util.auxiliary import set_pilot_state
+from pilot.util.container import execute
 from pilot.util.processes import get_cpu_consumption_time
 from pilot.util.config import config
 from pilot.util.filehandling import read_file, remove_core_dumps, get_guid, extract_lines_from_file, find_file
@@ -62,7 +63,7 @@ def control(queues, traces, args):
                 pass
             else:
                 exc_type, exc_obj, exc_trace = exc
-                logger.warning("thread \'%s\' received an exception from bucket: %s", thread.name, exc_obj)
+                logger.warning(f"thread \'{thread.name}\' received an exception from bucket: {exc_obj}")
 
                 # deal with the exception
                 # ..
@@ -140,11 +141,11 @@ def _validate_payload(job):
 
     # perform user specific validation
     pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
-    user = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+    user = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)
     try:
         status = user.validate(job)
     except Exception as error:
-        logger.fatal('failed to execute user validate() function: %s', error)
+        logger.fatal(f'failed to execute user validate() function: {error}')
         status = False
 
     return status
@@ -204,13 +205,13 @@ def execute_payloads(queues, traces, args):  # noqa: C901
             # this job is now to be monitored, so add it to the monitored_payloads queue
             put_in_queue(job, queues.monitored_payloads)
 
-            logger.info('job %s added to monitored payloads queue', job.jobid)
+            logger.debug(f'job {job.jobid} added to monitored payloads queue')
 
             try:
                 out = open(os.path.join(job.workdir, config.Payload.payloadstdout), 'wb')
                 err = open(os.path.join(job.workdir, config.Payload.payloadstderr), 'wb')
             except Exception as error:
-                logger.warning('failed to open payload stdout/err: %s', error)
+                logger.warning(f'failed to open payload stdout/err: {error}')
                 out = None
                 err = None
             send_state(job, args, 'starting')
@@ -222,7 +223,7 @@ def execute_payloads(queues, traces, args):  # noqa: C901
                 continue
 
             payload_executor = get_payload_executor(args, job, out, err, traces)
-            logger.info("will use payload executor: %s", payload_executor)
+            logger.info(f"will use payload executor: {payload_executor}")
 
             # run the payload and measure the execution time
             job.t0 = os.times()
@@ -238,17 +239,16 @@ def execute_payloads(queues, traces, args):  # noqa: C901
 
             # some HPO jobs will produce new output files (following lfn name pattern), discover those and replace the job.outdata list
             if job.is_hpo:
-                user = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user],
-                                  0)  # Python 2/3
+                user = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)
                 try:
                     user.update_output_for_hpo(job)
                 except Exception as error:
-                    logger.warning('exception caught by update_output_for_hpo(): %s', error)
+                    logger.warning(f'exception caught by update_output_for_hpo(): {error}')
                 else:
                     for dat in job.outdata:
                         if not dat.guid:
                             dat.guid = get_guid()
-                            logger.warning('guid not set: generated guid=%s for lfn=%s', dat.guid, dat.lfn)
+                            logger.warning(f'guid not set: generated guid={dat.guid} for lfn={dat.lfn}')
 
             #if traces.pilot['nr_jobs'] == 1:
             #    logger.debug('faking job failure in first multi-job')
@@ -262,11 +262,11 @@ def execute_payloads(queues, traces, args):  # noqa: C901
             #if job.piloterrorcodes:
             #    exit_code_interpret = 1
             #else:
-            user = __import__('pilot.user.%s.diagnose' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+            user = __import__('pilot.user.%s.diagnose' % pilot_user, globals(), locals(), [pilot_user], 0)
             try:
                 exit_code_interpret = user.interpret(job)
             except Exception as error:
-                logger.warning('exception caught: %s', error)
+                logger.warning(f'exception caught: {error}')
                 #exit_code_interpret = -1
                 job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.INTERNALPILOTPROBLEM)
 
@@ -289,7 +289,7 @@ def execute_payloads(queues, traces, args):  # noqa: C901
         except queue.Empty:
             continue
         except Exception as error:
-            logger.fatal('execute payloads caught an exception (cannot recover): %s, %s', error, traceback.format_exc())
+            logger.fatal(f'execute payloads caught an exception (cannot recover): {error}, {traceback.format_exc()}')
             if job:
                 job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.PAYLOADEXECUTIONEXCEPTION)
                 #queues.failed_payloads.put(job)
@@ -338,15 +338,15 @@ def get_logging_info(job, args):
 
     info_dic = {}
 
-    if 'logging=' not in job.infosys.queuedata.catchall and not job.realtimelogging:
+    if not job.realtimelogging:
         return {}
 
     # args handling
     info_dic['logname'] = args.realtime_logname if args.realtime_logname else "pilot-log"
     logserver = args.realtime_logging_server if args.realtime_logging_server else ""
 
-    pattern = r'logging\=(\S+)\;(\S+)\:\/\/(\S+)\:(\d+)'
-    info = findall(pattern, job.infosys.queuedata.catchall)
+    pattern = r'(\S+)\;(\S+)\:\/\/(\S+)\:(\d+)'
+    info = findall(pattern, config.Pilot.rtlogging)
 
     if not logserver and not info:
         logger.warning('not enough info available for activating real-time logging')
@@ -362,26 +362,10 @@ def get_logging_info(job, args):
             print(f'exception caught: {exc}')
             info_dic = {}
         else:
-            path = None
-            if 'tail' in job.debug_command:
-                filename = job.debug_command.split(' ')[-1]
-                logger.debug(f'filename={filename}')
-                counter = 0
-                path = None
-                maxwait = 5 * 60
-                while counter < maxwait and not args.graceful_stop.is_set():
-                    path = find_file(filename, job.workdir)
-                    if not path:
-                        logger.debug(f'file {filename} not found, waiting for max {maxwait} s')
-                        time.sleep(10)
-                    else:
-                        break
-                    counter += 10
-                if not path:
-                    logger.warning(f'file {filename} was not found for {maxwait} s, using default')
-            logf = path if path else config.Payload.payloadstdout
-            logger.info(f'using {logf} for real-time logging')
-            info_dic['logfiles'] = [logf]
+            # find the log file to tail
+            path = find_log_to_tail(job.debug_command, job.workdir, args, job.is_analysis())
+            logger.info(f'using {path} for real-time logging')
+            info_dic['logfiles'] = [path]
     else:
         items = logserver.split(':')
         info_dic['logging_type'] = items[0].lower()
@@ -409,7 +393,46 @@ def get_logging_info(job, args):
     return info_dic
 
 
-def run_realtimelog(queues, traces, args):
+def find_log_to_tail(debug_command, workdir, args, is_analysis):
+    """
+    Find the log file to tail in the RT logging.
+
+    :param debug_command: requested debug command (string).
+    :param workdir: job working directory (string).
+    :param args: pilot args object.
+    :param is_analysis: True for user jobs (Bool).
+    :return: path to log file (string).
+    """
+
+    path = ""
+    filename = ""
+    counter = 0
+    maxwait = 5 * 60
+
+    if 'tail' in debug_command:
+        filename = debug_command.split(' ')[-1]
+    elif is_analysis:
+        filename = 'tmp.stdout*'
+    if filename:
+        logger.debug(f'filename={filename}')
+        while counter < maxwait and not args.graceful_stop.is_set():
+            path = find_file(filename, workdir)
+            if not path:
+                logger.debug(f'file {filename} not found, waiting for max {maxwait} s')
+                time.sleep(10)
+            else:
+                break
+            counter += 10
+
+    # fallback to known log file if no other file could be found
+    if not path:
+        logger.warning(f'file {filename} was not found for {maxwait} s, using default')
+    logf = path if path else config.Payload.payloadstdout
+
+    return logf
+
+
+def run_realtimelog(queues, traces, args):  # noqa: C901
     """
     Validate finished payloads.
     If payload finished correctly, add the job to the data_out queue. If it failed, add it to the data_out queue as
@@ -430,35 +453,44 @@ def run_realtimelog(queues, traces, args):
             continue
 
         # wait with proceeding until the job is running
+        abort_loops = False
+        first1 = True
+        first2 = True
         while not args.graceful_stop.is_set():
-            if job.state == 'running':
-                logger.debug('job is running, time to start real-time logger [if needed]')
+
+            # note: in multi-job mode, the real-time logging will be switched off at the end of the job
+            while not args.graceful_stop.is_set():
+                if job.state == 'running':
+                    if first1:
+                        logger.debug('job is running, check if real-time logger is needed')
+                        first1 = False
+                    break
+                if job.state == 'stageout' or job.state == 'failed' or job.state == 'holding':
+                    if first2:
+                        logger.debug(f'job is in state {job.state}, continue to next job or abort (wait for graceful stop)')
+                        first2 = False
+                    time.sleep(10)
+                    continue
+                time.sleep(1)
+
+            if args.use_realtime_logging:
+                # always do real-time logging
+                job.realtimelogging = True
+                job.debug = True
+                abort_loops = True
+            elif job.debug and \
+                    (not job.debug_command or job.debug_command == 'debug' or 'tail' in job.debug_command) and \
+                    not args.use_realtime_logging:
+                job.realtimelogging = True
+                abort_loops = True
+
+            if abort_loops:
+                logger.info('time to start real-time logger')
                 break
-            if job.state == 'stageout' or job.state == 'failed':
-                logger.debug(f'job is in state {job.state}, continue to next job')
-                continue
-            time.sleep(1)
+            time.sleep(10)
 
-        if args.use_realtime_logging:
-            # always do real-time logging
-            job.realtimelogging = True
-            job.debug = True
-
-        logger.debug(f'debug={job.debug}')
-        logger.debug(f'debug_command={job.debug_command}')
-        logger.debug(f'args.use_realtime_logging={args.use_realtime_logging}')
-        if job.debug and (not job.debug_command or job.debug_command == 'debug' or 'tail' in job.debug_command) and not args.use_realtime_logging:
-            logger.info('turning on real-time logging')
-            job.realtimelogging = True
-
-        # testing
-        # job.realtimelogging = True
-        # reset info_dic if real-time logging is not wanted by the job
-        if not job.realtimelogging:
-            info_dic = None
         # only set info_dic once per job (the info will not change)
-        info_dic = get_logging_info(job, args) if not info_dic and job.realtimelogging else info_dic
-        logger.debug(f'info_dic={info_dic}')
+        info_dic = get_logging_info(job, args)
         if info_dic:
             args.use_realtime_logging = True
             realtime_logger = get_realtime_logger(args, info_dic, job.workdir, job.pilotsecrets)
@@ -468,8 +500,8 @@ def run_realtimelog(queues, traces, args):
 
         # If no realtime logger is found, do nothing and exit
         if realtime_logger is None:
-            logger.debug('realtime logger was not found, exiting')
-            break
+            logger.debug('realtime logger was not found, waiting ..')
+            continue
         else:
             logger.debug('realtime logger was found')
 
@@ -496,7 +528,7 @@ def set_cpu_consumption_time(job):
     job.cpuconsumptiontime = int(round(cpuconsumptiontime))
     job.cpuconsumptionunit = "s"
     job.cpuconversionfactor = 1.0
-    logger.info('CPU consumption time: %f %s (rounded to %d %s)', cpuconsumptiontime, job.cpuconsumptionunit, job.cpuconsumptiontime, job.cpuconsumptionunit)
+    logger.info(f'CPU consumption time: {cpuconsumptiontime} {job.cpuconsumptionunit} (rounded to {job.cpuconsumptiontime} {job.cpuconsumptionunit})')
 
 
 def perform_initial_payload_error_analysis(job, exit_code):
@@ -510,7 +542,7 @@ def perform_initial_payload_error_analysis(job, exit_code):
     """
 
     if exit_code != 0:
-        logger.warning('main payload execution returned non-zero exit code: %d', exit_code)
+        logger.warning(f'main payload execution returned non-zero exit code: {exit_code}')
 
     # look for singularity errors (the exit code can be zero in this case)
     path = os.path.join(job.workdir, config.Payload.payloadstderr)
@@ -521,7 +553,13 @@ def perform_initial_payload_error_analysis(job, exit_code):
         stderr = ''
         logger.info(f'file does not exist: {path}')
 
-    if exit_code != 0:
+    # check for memory errors first
+    if exit_code != 0 and job.subprocesses:
+        # scan for memory errors in dmesg messages
+        msg = scan_for_memory_errors(job.subprocesses)
+        if msg:
+            job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.PAYLOADOUTOFMEMORY, msg=msg)
+    elif exit_code != 0:
         msg = ""
 
         # are there any critical errors in the stdout?
@@ -579,6 +617,33 @@ def perform_initial_payload_error_analysis(job, exit_code):
             job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.COREDUMP)
 
 
+def scan_for_memory_errors(subprocesses):
+    """
+    Scan for memory errors in dmesg messages.
+
+    :param subprocesses: list of payload subprocesses.
+    :return: error diagnostics (string).
+    """
+
+    diagnostics = ""
+    search_str = 'Memory cgroup out of memory'
+    for pid in subprocesses:
+        logger.info(f'scanning dmesg message for subprocess={pid} for memory errors')
+        cmd = f'dmesg|grep {pid}'
+        _, out, _ = execute(cmd)
+        if search_str in out:
+            for line in out.split('\n'):
+                if search_str in line:
+                    diagnostics = line[line.find(search_str):]
+                    logger.warning(f'found memory error: {diagnostics}')
+                    break
+
+        if diagnostics:
+            break
+
+    return diagnostics
+
+
 def set_error_code_from_stderr(msg, fatal):
     """
     Identify specific errors in stderr and set the corresponding error code.
