@@ -127,57 +127,6 @@ def get_memory_monitor_setup(pid, pgrp, jobid, workdir, command, setup="", use_c
     return cmd, pid
 
 
-def get_memory_monitor_setup_old(pid, pgrp, jobid, workdir, command, setup="", use_container=True, transformation="", outdata=None, dump_ps=False):
-    """
-    Return the proper setup for the memory monitor.
-    If the payload release is provided, the memory monitor can be setup with the same release. Until early 2018, the
-    memory monitor was still located in the release area. After many problems with the memory monitor, it was decided
-    to use a fixed version for the setup. Currently, release 21.0.22 is used.
-
-    :param pid: job process id (int).
-    :param pgrp: process group id (int).
-    :param jobid: job id (int).
-    :param workdir: job work directory (string).
-    :param command: payload command (string).
-    :param setup: optional setup in case asetup can not be used, which uses infosys (string).
-    :param use_container: optional boolean.
-    :param transformation: optional name of transformation, e.g. Sim_tf.py (string).
-    :param outdata: optional list of output fspec objects (list).
-    :param dump_ps: should ps output be dumped when identifying prmon process? (Boolean).
-    :return: job work directory (string), pid for process inside container (int).
-    """
-
-    # try to get the pid from a pid.txt file which might be created by a container_script
-    pid = get_proper_pid(pid, pgrp, jobid, command=command, transformation=transformation, outdata=outdata, use_container=use_container, dump_ps=dump_ps)
-    if pid == -1:
-        logger.warning('process id was not identified before payload finished - will not launch memory monitor')
-        return "", pid
-
-    release = "22.0.1"
-    platform = "x86_64-centos7-gcc8-opt"
-    if not setup:
-        setup = get_asetup() + " Athena," + release + " --platform " + platform
-    interval = 60
-    if not setup.endswith(';'):
-        setup += ';'
-    # Decide which version of the memory monitor should be used
-    cmd = "%swhich prmon" % setup
-    exit_code, stdout, stderr = execute(cmd)
-    if stdout and "Command not found" not in stdout:
-        _cmd = "prmon "
-    else:
-        logger.warning('failed to find prmon, defaulting to old memory monitor: %d, %s' % (exit_code, stderr))
-        _cmd = "MemoryMonitor "
-        setup = setup.replace(release, "21.0.22")
-        setup = setup.replace(platform, "x86_64-slc6-gcc62-opt")
-
-    options = "--pid %d --filename %s --json-summary %s --interval %d" %\
-              (pid, get_memory_monitor_output_filename(), get_memory_monitor_summary_filename(), interval)
-    _cmd = "cd " + workdir + ";" + setup + _cmd + options
-
-    return _cmd, pid
-
-
 def get_proper_pid(pid, pgrp, jobid, command="", transformation="", outdata="", use_container=True, dump_ps=False):
     """
     Return a pid from the proper source to be used with the memory monitor.
@@ -607,7 +556,7 @@ def get_average_summary_dictionary_prmon(path):
 
     if dictionary:
         # Calculate averages and store all values
-        summary_dictionary = {"Max": {}, "Avg": {}, "Other": {}}
+        summary_dictionary = {"Max": {}, "Avg": {}, "Other": {}, "Time": {}}
 
         def filter_value(value):
             """ Inline function used to remove any string or None values from data. """
@@ -632,11 +581,16 @@ def get_average_summary_dictionary_prmon(path):
 
         # add the last of the rchar, .., values
         keys = ['rchar', 'wchar', 'read_bytes', 'write_bytes', 'nprocs']
+        time_keys = ['stime', 'utime']
+        keys = keys + time_keys
         # warning: should read_bytes/write_bytes be reported as rbytes/wbytes?
         for key in keys:
             value = get_last_value(dictionary.get(key, None))
             if value:
-                summary_dictionary["Other"][key] = value
+                if key in time_keys:
+                    summary_dictionary["Time"][key] = value
+                else:
+                    summary_dictionary["Other"][key] = value
 
     return summary_dictionary
 
