@@ -5,7 +5,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0
 #
 # Authors:
-# - Paul Nilsson, paul.nilsson@cern.ch, 2017-2021
+# - Paul Nilsson, paul.nilsson@cern.ch, 2017-2022
 
 import os
 import re
@@ -83,6 +83,7 @@ def display_architecture_info():
     Display OS/architecture information.
     The function attempts to use the lsb_release -a command if available. If that is not available,
     it will dump the contents of
+    WARNING: lsb_release will not be available on CentOS Stream 9
 
     :return:
     """
@@ -124,11 +125,15 @@ def get_batchsystem_jobid():
 
     # Condor (get jobid from classad file)
     if '_CONDOR_JOB_AD' in os.environ:
-        from subprocess import getoutput
-        out = getoutput('sed -n "s/^GlobalJobId.*\\"\\(.*\\)\\".*/\\1/p" %s' % os.environ.get("_CONDOR_JOB_AD"))
-        out = out.split('\n')[-1] if '\n' in out else out
-        return "Condor", out
-
+        try:
+            with open(os.environ.get("_CONDOR_JOB_AD"), 'r') as _fp:
+                for line in _fp:
+                    res = re.search(r'^GlobalJobId\s*=\s*"(.*)"', line)
+                    if res is None:
+                        continue
+                    return "Condor", res.group(1)
+        except OSError as exc:
+            logger.warning("failed to read HTCondor job classAd: %s", exc)
     return None, ""
 
 
