@@ -5,7 +5,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0
 #
 # Authors:
-# - Paul Nilsson, paul.nilsson@cern.ch, 2018-2021
+# - Paul Nilsson, paul.nilsson@cern.ch, 2018-2022
 
 import subprocess
 import logging
@@ -21,7 +21,6 @@ def execute(executable, **kwargs):
     """
     Execute the command and its options in the provided executable list.
     The function also determines whether the command should be executed within a container.
-    TODO: add time-out functionality.
 
     :param executable: command to be executed (string or list).
     :param kwargs (timeout, usecontainer, returnproc):
@@ -67,7 +66,7 @@ def execute(executable, **kwargs):
         try:
             stdout, stderr = process.communicate(timeout=kwargs.get('timeout', None))
         except subprocess.TimeoutExpired as exc:
-            _stderr = 'subprocess communicate sent TimeoutExpired: %s' % exc
+            _stderr = f'subprocess communicate sent TimeoutExpired: {exc}'
             logger.warning(_stderr)
             exit_code = errors.COMMANDTIMEDOUT
             process.kill()
@@ -98,7 +97,7 @@ def print_executable(executable):
             secret_key = sub_cmd.split('S3_SECRET_KEY=')[1]
             secret_key = 'S3_SECRET_KEY=' + secret_key
             executable_readable = executable_readable.replace(secret_key, 'S3_SECRET_KEY=********')
-    logger.info('executing command: %s', executable_readable)
+    logger.info(f'executing command: {executable_readable}')
 
 
 def containerise_executable(executable, **kwargs):
@@ -113,7 +112,7 @@ def containerise_executable(executable, **kwargs):
     job = kwargs.get('job')
 
     user = environ.get('PILOT_USER', 'generic').lower()  # TODO: replace with singleton
-    container = __import__('pilot.user.%s.container' % user, globals(), locals(), [user], 0)  # Python 2/3
+    container = __import__('pilot.user.%s.container' % user, globals(), locals(), [user], 0)
     if container:
         # should a container really be used?
         do_use_container = job.usecontainer if job else container.do_use_container(**kwargs)
@@ -127,7 +126,7 @@ def containerise_executable(executable, **kwargs):
             try:
                 executable = container.wrapper(executable, **kwargs)
             except Exception as exc:
-                diagnostics = 'failed to execute wrapper function: %s' % exc
+                diagnostics = f'failed to execute wrapper function: {exc}'
                 logger.fatal(diagnostics)
             else:
                 if executable == "":
