@@ -9,7 +9,6 @@
 # - Mario Lassnig, mario.lassnig@cern.ch, 2017
 # - Paul Nilsson, paul.nilsson@cern.ch, 2017-2022
 
-import subprocess
 import json
 import os
 import platform
@@ -27,9 +26,12 @@ from time import sleep, time
 from .filehandling import write_file
 from .config import config
 from .constants import get_pilot_version
+from .container import execute
+from pilot.common.errorcodes import ErrorCodes
 
 import logging
 logger = logging.getLogger(__name__)
+errors = ErrorCodes()
 
 _ctx = namedtuple('_ctx', 'ssl_context user_agent capath cacert')
 _ctx.ssl_context = None
@@ -304,7 +306,8 @@ def execute_request(req):
     :return: status (int), output (string).
     """
 
-    return subprocess.getstatusoutput(req)
+    exit_code, stdout, _ = execute(req)
+    return exit_code, stdout
 
 
 def execute_urllib(url, data, plain, secure):
@@ -339,9 +342,9 @@ def get_urlopen_output(req, context):
     try:
         output = urllib.request.urlopen(req, context=context)
     except urllib.error.HTTPError as exc:
-        logger.warning('server error (%s): %s' % (exc.code, exc.read()))
+        logger.warning(f'server error ({exc.code}): {exc.read()}')
     except urllib.error.URLError as exc:
-        logger.warning('connection error: %s' % exc.reason)
+        logger.warning(f'connection error: {exc.reason}')
     else:
         exitcode = 0
 
@@ -365,6 +368,16 @@ def send_update(update_function, data, url, port, job=None):
     attempt = 0
     done = False
     res = None
+
+    if os.environ.get('REACHED_MAXTIME', None) and update_function == 'updateJob':
+        data['state'] = 'failed'
+        if job:
+            job.state = 'failed'
+            msg = 'the max batch system time limit has been reached'
+            logger.warning(msg)
+            job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.REACHEDMAXTIME, msg=msg)
+            add_error_codes(data, job)
+
     while attempt < max_attempts and not done:
         logger.info(f'server update attempt {attempt + 1}/{max_attempts}')
 
@@ -401,19 +414,20 @@ def send_update(update_function, data, url, port, job=None):
     return res
 
 
-def get_panda_server(url, port):
+def get_panda_server(url, port, update_server=True):
     """
     Get the URL for the PanDA server.
+    The URL will be randomized if the server can be contacted (otherwise fixed).
 
     :param url: URL string, if set in pilot option (port not included).
     :param port: port number, if set in pilot option (int).
-    :return: full URL (either from pilot options or from config file)
+    :param update_server: True if the server can be contacted (Boolean).
+    :return: full URL (either from pilot options or from config file).
     """
 
     if url != '':
         parsedurl = url.split('://')
         scheme = None
-        loc = None
         if len(parsedurl) == 2:
             scheme = parsedurl[0]
             loc = parsedurl[1]
@@ -436,6 +450,9 @@ def get_panda_server(url, port):
         if not pandaserver.startswith('http'):
             pandaserver = 'https://' + pandaserver
 
+    if not update_server:
+        return pandaserver
+
     # add randomization for PanDA server
     default = 'pandaserver.cern.ch'
     if default in pandaserver:
@@ -444,3 +461,34 @@ def get_panda_server(url, port):
         logger.debug(f'updated {default} to {pandaserver}')
 
     return pandaserver
+
+
+def add_error_codes(data, job):
+    """
+    Add error codes to data structure.
+
+    :param data: data dictionary.
+    :param job: job object.
+    :return:
+    """
+
+    # error codes
+    pilot_error_code = job.piloterrorcode
+    pilot_error_codes = job.piloterrorcodes
+    if pilot_error_codes != []:
+        logger.warning(f'pilotErrorCodes = {pilot_error_codes} (will report primary/first error code)')
+        data['pilotErrorCode'] = pilot_error_codes[0]
+    else:
+        data['pilotErrorCode'] = pilot_error_code
+
+    # add error info
+    pilot_error_diag = job.piloterrordiag
+    pilot_error_diags = job.piloterrordiags
+    if pilot_error_diags != []:
+        logger.warning(f'pilotErrorDiags = {pilot_error_diags} (will report primary/first error diag)')
+        data['pilotErrorDiag'] = pilot_error_diags[0]
+    else:
+        data['pilotErrorDiag'] = pilot_error_diag
+    data['transExitCode'] = job.transexitcode
+    data['exeErrorCode'] = job.exeerrorcode
+    data['exeErrorDiag'] = job.exeerrordiag
