@@ -24,7 +24,8 @@ from pilot.util.filehandling import get_disk_usage, remove_files, get_local_file
 from pilot.util.loopingjob import looping_job
 from pilot.util.math import convert_mb_to_b, human2bytes
 from pilot.util.parameters import convert_to_int, get_maximum_input_sizes
-from pilot.util.processes import get_current_cpu_consumption_time, kill_processes, get_number_of_child_processes
+from pilot.util.processes import get_current_cpu_consumption_time, kill_processes, get_number_of_child_processes,\
+    get_subprocesses
 from pilot.util.timing import get_time_since
 from pilot.util.workernode import get_local_disk_space, check_hz
 
@@ -67,6 +68,9 @@ def job_monitor_tasks(job, mt, args):
             job.cpuconversionfactor = 1.0
             logger.info(f'CPU consumption time for pid={job.pid}: {cpuconsumptiontime} (rounded to {job.cpuconsumptiontime})')
 
+        # keep track of the subprocesses running (store payload subprocess PIDs)
+        store_subprocess_pids(job)
+
         # check how many cores the payload is using
         time_since_start = get_time_since(job.jobid, PILOT_PRE_PAYLOAD, args)  # payload walltime
         set_number_used_cores(job, time_since_start)
@@ -186,7 +190,7 @@ def set_number_used_cores(job, walltime):
     """
 
     pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
-    cpu = __import__('pilot.user.%s.cpu' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+    cpu = __import__('pilot.user.%s.cpu' % pilot_user, globals(), locals(), [pilot_user], 0)
 
     kwargs = {'job': job, 'walltime': walltime}
     cpu.set_core_counts(**kwargs)
@@ -206,7 +210,7 @@ def verify_memory_usage(current_time, mt, job):
     show_memory_usage()
 
     pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
-    memory = __import__('pilot.user.%s.memory' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+    memory = __import__('pilot.user.%s.memory' % pilot_user, globals(), locals(), [pilot_user], 0)
 
     if not memory.allow_memory_usage_verifications():
         return 0, ""
@@ -265,12 +269,13 @@ def verify_user_proxy(current_time, mt):
     """
 
     pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
-    userproxy = __import__('pilot.user.%s.proxy' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+    userproxy = __import__('pilot.user.%s.proxy' % pilot_user, globals(), locals(), [pilot_user], 0)
 
     # is it time to verify the proxy?
-    proxy_verification_time = convert_to_int(config.Pilot.proxy_verification_time, default=600)
+    proxy_verification_time = 60  # convert_to_int(config.Pilot.proxy_verification_time, default=600)
     if current_time - mt.get('ct_proxy') > proxy_verification_time:
         # is the proxy still valid?
+        logger.debug('calling verify_proxy with test=True')
         exit_code, diagnostics = userproxy.verify_proxy(test=False)  # use test=True to test expired proxy
         if exit_code != 0:
             return exit_code, diagnostics
@@ -415,10 +420,10 @@ def utility_monitor(job):
     """
 
     pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
-    usercommon = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+    usercommon = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)
 
     # loop over all utilities
-    for utcmd in list(job.utilities.keys()):  # E.g. utcmd = MemoryMonitor, Python 2/3
+    for utcmd in list(job.utilities.keys()):  # E.g. utcmd = MemoryMonitor
 
         # make sure the subprocess is still running
         utproc = job.utilities[utcmd][0]
@@ -655,8 +660,8 @@ def get_max_allowed_work_dir_size():
     except Exception as error:
         max_input_size = get_max_input_size()
         maxwdirsize = max_input_size + config.Pilot.local_size_limit_stdout * 1024
-        logger.info("work directory size check will use %d B as a max limit (maxinputsize [%d B] + local size limit for"
-                    " stdout [%d B])", maxwdirsize, max_input_size, config.Pilot.local_size_limit_stdout * 1024)
+        logger.info(f"work directory size check will use {maxwdirsize} B as a max limit (maxinputsize [{max_input_size}"
+                    f"B] + local size limit for stdout [{config.Pilot.local_size_limit_stdout * 1024} B])")
         logger.warning(f'conversion caught exception: {error}')
     else:
         # grace margin, as discussed in https://its.cern.ch/jira/browse/ATLASPANDA-482
@@ -735,3 +740,22 @@ def check_output_file_sizes(job):
             logger.info(f'output file size check: skipping output file {path} since it does not exist')
 
     return exit_code, diagnostics
+
+
+def store_subprocess_pids(job):
+    """
+    Keep track of all running subprocesses.
+
+    :param job: job object.
+    :return:
+    """
+
+    # is the payload running?
+    if job.pid:
+        # get all subprocesses
+        _subprocesses = get_subprocesses(job.pid)
+        # merge lists without duplicates
+        job.subprocesses = list(set(job.subprocesses + _subprocesses))
+        logger.debug(f'payload subprocesses: {job.subprocesses}')
+    else:
+        logger.debug('payload not running (no subprocesses)')
